/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.handlers;

import net.sourceforge.wurfl.core.request.UserAgentNormalizerChain;
import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.*;
import net.sourceforge.wurfl.core.request.normalizer.specific.*;

import java.util.Collections;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * A factory for user-agent {@link Handler}.
 * <p/>
 * <p>
 * This class build a {@link Map} of user-agent {@link Handler} by a key.
 * </p>
 *
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: HandlersFactory.java 604 2011-01-05 13:05:00Z asres.fantayeneh $
 */
public class HandlersFactory {


    private static Map handlers = new LinkedHashMap();

    static {

        UserAgentNormalizerChain genericNormalizers = createGenericNormalizers();


        handlers.put(HandlerConstants.NOKIA, new NokiaHandler(genericNormalizers));
        handlers.put(HandlerConstants.LGUPLUS, new LGUPLUSHandler(genericNormalizers));
        UserAgentNormalizer androidNormalizer = genericNormalizers.add(new AndroidNormalizer());
        handlers.put(HandlerConstants.ANDROID, new AndroidHandler(androidNormalizer));
        handlers.put(HandlerConstants.SONY_ERICSSON, new SonyEricssonHandler(genericNormalizers));


        handlers.put(HandlerConstants.MOTOROLA, new MotorolaHandler(genericNormalizers));
        handlers.put(HandlerConstants.BLACKBERRY, new BlackBerryHandler(genericNormalizers));

        handlers.put(HandlerConstants.SIEMENS, new SiemensHandler(genericNormalizers));
        handlers.put(HandlerConstants.SAGEM, new SagemHandler(genericNormalizers));

        handlers.put(HandlerConstants.SAMSUNG, new SamsungHandler(genericNormalizers));
        handlers.put(HandlerConstants.PANASONIC, new PanasonicHandler(genericNormalizers));

        handlers.put(HandlerConstants.NEC, new NecHandler(genericNormalizers));
        handlers.put(HandlerConstants.QTEK, new QtekHandler(genericNormalizers));

        handlers.put(HandlerConstants.MITSUBISHI, new MitsubishiHandler(genericNormalizers));
        handlers.put(HandlerConstants.PHILIPS, new PhilipsHandler(genericNormalizers));

        UserAgentNormalizer lgNormalizer = genericNormalizers.add(new LGNormalizer());
        handlers.put(HandlerConstants.LG, new LGHandler(lgNormalizer));
        handlers.put(HandlerConstants.APPLE, new AppleHandler(genericNormalizers));

        handlers.put(HandlerConstants.KYOCERA, new KyoceraHandler(genericNormalizers));
        handlers.put(HandlerConstants.ALCATEL, new AlcatelHandler(genericNormalizers));

        handlers.put(HandlerConstants.SHARP, new SharpHandler(genericNormalizers));
        handlers.put(HandlerConstants.SANYO, new SanyoHandler(genericNormalizers));

        handlers.put(HandlerConstants.BENQ, new BenQHandler(genericNormalizers));
        handlers.put(HandlerConstants.PANTECH, new PantechHandler(genericNormalizers));

        handlers.put(HandlerConstants.TOSHIBA, new ToshibaHandler(genericNormalizers));
        handlers.put(HandlerConstants.GRUNDIG, new GrundigHandler(genericNormalizers));

        handlers.put(HandlerConstants.HTC, new HTCHandler(genericNormalizers));

        handlers.put(HandlerConstants.BOT, new BotHandler(genericNormalizers));
        handlers.put(HandlerConstants.SPV, new SPVHandler(genericNormalizers));

        handlers.put(HandlerConstants.WINDOWS_CE, new WindowsCEHandler(genericNormalizers));
        handlers.put(HandlerConstants.PORTALMMM, new PortalmmmHandler(genericNormalizers));

        handlers.put(HandlerConstants.DOCOMO, new DoCoMoHandler(genericNormalizers));
        handlers.put(HandlerConstants.KDDDI, new KDDIHandler(genericNormalizers));

        handlers.put(HandlerConstants.VODAFONE, new VodafoneHandler(genericNormalizers));


        handlers.put(HandlerConstants.OPERA_MINI, new OperaMiniHandler(genericNormalizers));

        handlers.put(HandlerConstants.MAEMO_BROWSER, new MaemoBrowserHandler(genericNormalizers.add(new MaemoBrowserNormalizer())));


        handlers.put(HandlerConstants.CHROME, new ChromeHandler(genericNormalizers.add(new ChromeNormalizer())));
        handlers.put(HandlerConstants.AOL, new AOLHandler(genericNormalizers));
        handlers.put(HandlerConstants.OPERA, new OperaHandler(genericNormalizers));
        handlers.put(HandlerConstants.KONQUEROR, new KonquerorHandler(genericNormalizers.add(new KonquerorNormalizer())));
        handlers.put(HandlerConstants.SAFARI, new SafariHandler(genericNormalizers.add(new SafariNormalizer())));
        handlers.put(HandlerConstants.FIREFOX, new FirefoxHandler(genericNormalizers.add(new FirefoxNormalizer())));
        handlers.put(HandlerConstants.MSIE, new MSIEHandler(genericNormalizers.add(new MSIENormalizer())));

        handlers.put(HandlerConstants.CATCH_ALL, new CatchAllHandler(genericNormalizers));
    }

    private static UserAgentNormalizerChain createGenericNormalizers() {
        return new UserAgentNormalizerChain(
                new UserAgentNormalizer[]{
                        new SerialNumberNormalizer(),
                        new BlackBerryNormalizer(),
                        new UPLinkNormalizer(),
                        new YesWAPNormalizer(),
                        new BabelFishNormalizer(),
                        new LocaleRemover()
                }
        );
    }

    /**
     * Return the {@link Map} containig the {@link Handler}s. It is a
     *
     * @return A {@link Collections.UnmodifiableMap} containig the {@link Handler} by
     *         handlers key.
     */
    public Map create() {
        return Collections.unmodifiableMap(handlers);
    }
}