/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.handlers;


import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.utils.StringUtils;

/**
 * Intercept all UAs containing "Samsung/SGH" or starting with one of the
 * following "SEC-", "Samsung", "SAMSUNG", "SPH", "SGH", "SCH"
 *
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: SamsungHandler.java 544 2010-09-30 11:34:38Z asres.fantayeneh $
 */
public class SamsungHandler extends Handler {


    public SamsungHandler() {
    }

    public SamsungHandler(UserAgentNormalizer normalizer) {
        super(normalizer);
    }

    private static final String[] SAMSUNG_PREFIXES = new String[]{"SEC-", "SAMSUNG", "SPH", "SGH", "SCH"};
    private static final String[] SAMSUNG_INFIXES = new String[]{"Samsung/SGH", "Samsung"};

    public boolean canHandle(String userAgent) {
        return (StringUtils.containsAnyOf(userAgent, SAMSUNG_INFIXES)   
                || StringUtils.startsWithAnyOf(userAgent, SAMSUNG_PREFIXES));
    }

}
