/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.handlers.matchers;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.LinkedHashMap;
import java.util.Map;
import java.util.SortedSet;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: AndroidMatcher.java 596 2010-12-29 18:02:04Z asres.fantayeneh $
 */
public class AndroidMatcher extends AbstractMatcher {


    public AndroidMatcher(Handler handler) {
        super(handler);
    }

    protected String lookForMatchingUserAgent(SortedSet userAgentsSet,
                                              String userAgent) {
        int tolerance = StringUtils.indexOfOrLength(userAgent, " ", StringUtils.indexOfOrLength(userAgent, "Android"));
        return StringUtils.risMatch(userAgentsSet, userAgent, tolerance);
    }


    private static final Map ANDROIDS = new LinkedHashMap();
    
    static {
        ANDROIDS.put("", "generic_android");
        ANDROIDS.put("1_5", "generic_android_ver1_5");
        ANDROIDS.put("1_6", "generic_android_ver1_6");
        ANDROIDS.put("2_0", "generic_android_ver2");
        ANDROIDS.put("2_1", "generic_android_ver2_1");
        ANDROIDS.put("2_2", "generic_android_ver2_2");
    }

    private static final String GENERIC_ANDROID = "generic_android";
    
    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        String userAgent = request.getUserAgent();
        if(isFroyo(userAgent)) {
            return "generic_android_ver2_2";
        }
        final String version = androidOsVersion(userAgent);
        String deviceId = (String) ANDROIDS.get(version);
        if(deviceId != null) {
            return deviceId;
        }

        return GENERIC_ANDROID;
    }

    private boolean isFroyo(String userAgent) {
        return org.apache.commons.lang.StringUtils.contains(userAgent, "Froyo");
    }

    private static final Pattern ANDROID_OS_VERSION_PATTERN = Pattern.compile("Android[\\s/](\\d).(\\d)");

    private String androidOsVersion(String userAgent) {
        Matcher matcher = ANDROID_OS_VERSION_PATTERN.matcher(userAgent);
        return matcher.find() ? (matcher.group(1)+ "_" + matcher.group(2)) : "";
    }
}
