/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.handlers.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.Iterator;
import java.util.LinkedHashMap;
import java.util.Map;

/**
 * @author Fantayeneh Asres Gizaw
 */
public class LGUPLUSMatcher extends AbstractMatcher {

    public LGUPLUSMatcher(Handler handler) {
        super(handler);
    }

    protected String applyConclusiveMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        return Constants.GENERIC;
    }


    private static final Map LGPLUSES = new LinkedHashMap();

    static {
        LGPLUSES.put("generic_lguplus_rexos_facebook_browser", new String[]{"Windows NT 5", "POLARIS"});
        LGPLUSES.put("generic_lguplus_rexos_webviewer_browser", new String[]{"Windows NT 5"});
        LGPLUSES.put("generic_lguplus_winmo_facebook_browser", new String[]{"Windows CE", "POLARIS"});
        LGPLUSES.put("generic_lguplus_android_webkit_browser", new String[]{"Android", "AppleWebKit"});

    }

    protected String applyRecoveryMatch(WURFLRequest request, FilteredDevices filteredDevices) {
        for(Iterator itx = LGPLUSES.entrySet().iterator(); itx.hasNext();) {
            Map.Entry entry = (Map.Entry) itx.next(); 
            if(StringUtils.containsAllOf(request.getUserAgent(), (String[]) entry.getValue())) {
                return (String) entry.getKey();
            }
        }
        return "generic_lguplus";
    }
}
