/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.handlers.matchers;

import net.sourceforge.wurfl.core.Constants;
import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.handlers.classifiers.FilteredDevices;
import net.sourceforge.wurfl.core.request.WURFLRequest;
import org.apache.commons.lang.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: NokiaMatcher.java 596 2010-12-29 18:02:04Z asres.fantayeneh $
 */
public class NokiaMatcher extends AbstractMatcher {

    public NokiaMatcher(Handler handler) {
        super(handler);
    }

    /**
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

        int tolerance = net.sourceforge.wurfl.core.utils.StringUtils.indexOfAnyOrLength(userAgent, new String[]{"/", " "}, userAgent.indexOf("Nokia"));
        if (logger.isDebugEnabled()) {
            logger.debug("Applying RIS with tolerance [" + tolerance + "] UA: " + userAgent);
        }
        return net.sourceforge.wurfl.core.utils.StringUtils.risMatch(userAgentsSet, userAgent, tolerance);
    }

    /**
     * Search for "Series60" and "Series80". Return "nokia_generic_series60" and
     * "nokia_generic_series80" respectively in case of success
     */
    protected String applyRecoveryMatch(WURFLRequest request,
                                        FilteredDevices filteredDevices) {
        
        String userAgent = request.getUserAgent();

        if (logger.isDebugEnabled()) {
            logger.debug("Applying Nokia Recovery Match on User-Agent: "
                    + userAgent);
        }

        if (StringUtils.contains(userAgent, "Series60")) {
            return "nokia_generic_series60";
        }
        if (StringUtils.contains(userAgent, "Series80")) {
            return "nokia_generic_series80";
        }
        return Constants.GENERIC;

	}

}
