/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.handlers.matchers;

import net.sourceforge.wurfl.core.handlers.Handler;
import net.sourceforge.wurfl.core.utils.StringUtils;

import java.util.SortedSet;

/**
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * @version $Id: SamsungMatcher.java 596 2010-12-29 18:02:04Z asres.fantayeneh $
 */
public class SamsungMatcher extends AbstractMatcher {

    public SamsungMatcher(Handler handler) {
        super(handler);
    }

    /**
     * <p>
     * If UA starts with one of the following ("SEC-", "SAMSUNG-", "SCH"), apply
     * default.
     * </p>
     * <p>
     * Else if UA starts with one of the following ("Samsung-","SPH", "SGH" ), apply RIS(FP).
     * </p>
     * <p>
     * Else if UA starts with "SAMSUNG/", apply RIS(SS).
     * </p>
     */
    protected String lookForMatchingUserAgent(SortedSet userAgentsSet, String userAgent) {

        int tolerance = tolerance(userAgent);
        if (logger.isDebugEnabled()) {
            logger.debug("Applying RIS with Tolerance[" + tolerance + "] on UA: " + userAgent);
        }
        return StringUtils.risMatch(userAgentsSet, userAgent, tolerance);

    }

    private static final String[] SAMSUNGS = new String[]{"SEC-", "SAMSUNG-", "SCH", "Samsung", "SPH", "SGH", "SAMSUNG/"};
    private static final String[] THRESHOLD_CHARACTERS = new String[] {" ", "/"};
    private int tolerance(String userAgent) {
        for(int i = 0; i < SAMSUNGS.length; i++) {
            int index = userAgent.indexOf(SAMSUNGS[i]);
            if(index != -1) {
                return StringUtils.indexOfAnyOrLength(userAgent, THRESHOLD_CHARACTERS, index);
            }
        }
        return userAgent.length();
    }

}
