/**
 * This file is released under the GNU General Public License.
 * Refer to the COPYING file distributed with this package.
 *
 * Copyright (c) 2008-2010 WURFL-Pro srl
 */

package net.sourceforge.wurfl.core.request;

import net.sourceforge.wurfl.core.request.normalizer.UserAgentNormalizer;
import net.sourceforge.wurfl.core.request.normalizer.generic.*;
import org.apache.commons.logging.Log;
import org.apache.commons.logging.LogFactory;

/**
 * UserAgentNormalizerFactory default implementation.
 * 
 * <p>
 * Build a UserAgentNormalizerChain with the WURFL UserAgentNormalizers.
 * </p>
 * 
 * @author Fantayeneh Asres Gizaw
 * @author Filippo De Luca
 * 
 * @version $Id: DefaultUserAgentNormalizerFactory.java 596 2010-12-29 18:02:04Z asres.fantayeneh $
 */
public class DefaultUserAgentNormalizerFactory implements UserAgentNormalizerFactory {

	/** Log */
	private static final Log LOG = LogFactory.getLog(DefaultUserAgentNormalizerFactory.class);

	/**
	 * {@inheritDoc}
	 * 
	 * @return UserAgentNormalizerChain
	 */
	public UserAgentNormalizer create() {
		
		LOG.debug("Creating UserAgentNormalizerChain...");

		UserAgentNormalizerChain chain = new UserAgentNormalizerChain();
		chain.add(new SerialNumberNormalizer());
		chain.add(new BlackBerryNormalizer());
		chain.add(new UPLinkNormalizer());
		chain.add(new YesWAPNormalizer());
		chain.add(new BabelFishNormalizer());
		
		return chain;
	}

}
